<template>
	<div class="pc-prompts">
		<div class="title flex items-center justify-between">
			<div class="flex item-center">
				<span>提问示例</span>
				<span class="split"></span>
				<span class="change cursor-pointer" @click="advanceExampleClick">高级示例 ></span>
			</div>
			<div class="cursor-pointer">
				<span class="mr-1 changeBatch" @click="batchChange">换一批</span>
				<i class="iconfont icon-shuaxin"></i>
			</div>
		</div>

		<div class="main">
			<div
				class="main_item flex items-center cursor-pointer"
				v-for="(item, index) in state.exampleContent"
				:key="index"
				:class="{ main_item_active: item.sample_id === activeSampleId }"
				@click="changeExample(item)"
			>
				<div class="left flex items-center justify-center" :class="['color' + index]">
					<img :src="item.Icon" alt="" />
				</div>
				<div class="right">
					<h4>{{ item.sample_title }}</h4>
					<p>{{ item.sample_question }}</p>
				</div>
			</div>
		</div>
		<el-drawer v-model="state.isShowAdvanceExample" direction="rtl" size="354">
			<template #header style="padding: 30px 20px 26px">
				<div class="box-border w100 bg-[#e0e7fb] relative flex items-center justify-center">
					<div
						class="box-border flex w-[203px] h-[32px] rounded-md items-center justify-between cursor-pointer relative border border-solid border-[#2c2d33]"
					>
						<div
							class="tabbar-item"
							:class="state.activeName === item.ID ? 'set-tabbar-active' : ''"
							@click="handleTabClick(item)"
							v-for="item in state.tabNameList"
							:key="item.ID"
						>
							{{ item.Name }}
						</div>
					</div>
				</div>
			</template>
			<div class="box-border w-[354px] flex-1 min-h-0 bg-[#e0e7fb]" v-show="state.activeName == 1">
				<div class="flex flex-col w100 h100 pt-0 pr-[15px] pb-0 pl-[20px] overflow-auto">
					<div class="flex items-center w100 h-[30px] border border-solid border-[#b2b2b2] transition-[border-color 1s] rounded-2xl">
						<el-input v-model="state.searchInput" placeholder="搜索更多" class="set-input" :prefix-icon="Search"> </el-input>
					</div>
					<div class="mt20 w100 relative">
						<div
							class="overflow-hidden max-h-[36px] transition-[max-height 0.2s] w100 flex flex-wrap text-xs leading-[14px] m-[-5px]"
							:class="{ 'set-expand-active': state.isShowExpand }"
						>
							<div
								v-for="item in state.exampleTabList"
								:key="item.ID"
								:class="{ 'set-label-active': state.activeLabelName === item.ID }"
								@click="handleLabelClick(item)"
								class="cursor-pointer m-[5px] py-[5px] px-[10px] rounded-xl border border-solid border-[#b2b2b2] bg-[#e0e7f] text-[#4c4c4c] transition-[background-color .1s, color .1s, border-color .1s]"
							>
								{{ item.Title }}
							</div>
						</div>
						<div class="bg-[#e0e7fb] absolute right-0 top-0 text-[#131313] w-[30px] h-[26px] cursor-pointer flex items-center">
							<i class="iconfont icon-bolangneng" title="展开" @click="handleExpandClick(1)" v-show="!state.isShowExpand"></i>
							<i class="iconfont icon-zhongduancanshu" title="收缩" @click="handleExpandClick(2)" v-show="state.isShowExpand"></i>
						</div>
						<div class="mt20 w100">
							<div class="w100 pb-[20px]" v-for="item in state.exampleContentList" :key="item.sample_id">
								<div class="cursor-pointer flex box-border p-[12px] w100 rounded bg-[#f5f7fd] transition-[background-color .2s]">
									<i
										class="iconfont icon-chazhaobiaodanliebiao pl-[2px] w-[16px] h-[16px] font12 text-[#fff] transform-[scale(.85)] rounded-[50%]"
										:style="`background-color:${item.BgColor}`"
									></i>
									<div class="ml-6 flex-1 min-w-0">
										<div class="text-sm text-[#000] m-0 p-0 font-bold">{{ item.sample_title }}</div>
										<div class="mt-[6px] text-[13px] text-[#666] h-[20px] whitespace-nowrap text-ellipsis overflow-hidden">
											{{ item.sample_question }}
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class="box-border w-[354px] flex-1 min-h-0 bg-[#e0e7fb]" v-show="state.activeName == 2">
				<div class="flex flex-col w100 h100 pt-0 pr-[15px] pb-0 pl-[20px] overflow-auto">
					<div class="flex items-center w100 h-[30px] border border-solid border-[#b2b2b2] transition-[border-color 1s] rounded-2xl">
						<el-input v-model="state.searchInput" placeholder="搜索更多" class="set-input" :prefix-icon="Search"> </el-input>
					</div>
					<div class="mt20 w100 relative">
						<div
							class="overflow-hidden max-h-[36px] transition-[max-height 0.2s] w100 flex flex-wrap text-xs leading-[14px] m-[-5px]"
							:class="{ 'set-expand-active': state.isShowExpand }"
						>
							<div
								v-for="item in state.instructList"
								:key="item.ID"
								:class="{ 'set-label-active': state.activeInstructName === item.ID }"
								@click="handleInstructClick(item)"
								class="cursor-pointer m-[5px] py-[5px] px-[10px] rounded-xl border border-solid border-[#b2b2b2] bg-[#e0e7f] text-[#4c4c4c] transition-[background-color .1s, color .1s, border-color .1s]"
							>
								{{ item.Title }}
							</div>
						</div>
						<div class="bg-[#e0e7fb] absolute right-0 top-0 text-[#131313] w-[30px] h-[26px] cursor-pointer flex items-center">
							<i class="iconfont icon-bolangneng" title="展开" @click="handleExpandClick(1)" v-show="!state.isShowExpand"></i>
							<i class="iconfont icon-zhongduancanshu" title="收缩" @click="handleExpandClick(2)" v-show="state.isShowExpand"></i>
						</div>
						<div class="mt20 w100">
							<div
								class="w100 pb-[20px] flex overflow-auto flex-col"
								v-for="item in state.instructContentList"
								:key="item.template_id"
							>
								<div class="bg-[#f5f7fd] p-[12px] transition-[background-color .2s] flex flex-col rounded-2xl">
									<div class="flex justify-between">
										<span class="set-title">{{ item.template_title }}</span>
									</div>
									<div class="example-body ellipsis">{{ item.template_value }}</div>
									<div class="example-bottom">
										<span class="example-item">{{ item.template_type }}</span>
										<el-button type="primary" class="set-button">使用</el-button>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</el-drawer>
	</div>
</template>

<script setup lang="ts">
import { Search } from '@element-plus/icons-vue';
import { computed, onMounted, reactive } from 'vue';
import { getSelectSample, getUserTemplateList } from '/@/api/ai/chat';
import { activeSampleId } from '/@/stores/chatRoom';
import emitter from '/@/utils/mitt';
let state = reactive({
	exampleContent: [],
	exampleRandomContent: [],
	tabNameList: [
		{ ID: 1, Name: '提问示例' },
		{ ID: 2, Name: '指令模板' },
	],
	isShowAdvanceExample: false,
	activeName: 1,
	searchInput: '',
	exampleTabList: [
		{
			ID: 1,
			Title: '工作',
		},
		{
			ID: 2,
			Title: '职场',
		},
		{
			ID: 3,
			Title: '科学',
		},
		{
			ID: 4,
			Title: '求职',
		},
		{
			ID: 5,
			Title: '新能源,汽车,数据',
		},
		{
			ID: 6,
			Title: '写作',
		},
		{
			ID: 7,
			Title: '学习',
		},
		{
			ID: 8,
			Title: '创作',
		},
	],
	instructList: [
		{
			ID: 1,
			Title: '文学构思',
		},
		{
			ID: 2,
			Title: '语言翻译',
		},
		{
			ID: 3,
			Title: '高效策划',
		},
		{
			ID: 4,
			Title: '顾问专家',
		},
		{
			ID: 5,
			Title: '代码编程',
		},
		{
			ID: 6,
			Title: '办公写作',
		},
		{
			ID: 7,
			Title: '健康管家',
		},
		{
			ID: 8,
			Title: '发现探索',
		},
	],
	exampleContentList: [],
	instructContentList: [],

	activeLabelName: 0,
	activeInstructName: 0,
	isShowExpand: false,
});
onMounted(() => {
	getSelectListSample();
	getUserTemplate();
});
const groupedArray = computed(() => {
	const groups = [];
	let i = 0;
	while (state.exampleRandomContent.length > i) {
		groups.push(state.exampleRandomContent.slice(i, (i += 4)));
	}
	return groups;
});
const getSelectListSample = async () => {
	const res = await getSelectSample({
		section_b_id: '',
	});
	// console.log(res, 63);
	state.exampleRandomContent = res.samples;

	const array = [];
	res.samples.forEach((sample, index) => {
		sample.Icon = '/static/images/wave/ChatImg.png';
		sample.BgColor = randomHexColor();
		if (index < 4) {
			array.push(sample);
		}
	});
	state.exampleContentList = res.samples;
	state.exampleContent = array;
};

const changeExample = (item) => {
	emitter.emit('updateChatInput', item.sample_question);
	activeSampleId.value = item.sample_id;
};
//获取用户模板
const getUserTemplate = async () => {
	const res = await getUserTemplateList();
	state.instructContentList = res.templates;
};
//换一批
const batchChange = () => {
	const index = Math.floor(Math.random() * groupedArray.value.length);
	state.exampleContent = groupedArray.value[index];
	// console.log(state.exampleContent, 341);
};
//高级示例
const advanceExampleClick = () => {
	state.isShowAdvanceExample = true;
};
//切换到指令/提问
const handleTabClick = (item) => {
	state.activeName = item.ID;
};
//标签点击事件(提问示例)
const handleLabelClick = (item) => {
	state.activeLabelName = item.ID;
};
//标签点击事件(指令模板)
const handleInstructClick = (item) => {
	state.activeInstructName = item.ID;
};

//展开收起
const handleExpandClick = (type) => {
	if (type == 1) {
		state.isShowExpand = true;
	} else {
		state.isShowExpand = false;
	}
};
//随机生成颜色
const randomHexColor = () => {
	return `#${Math.floor(Math.random() * 16777215)
		.toString(16)
		.padEnd(6, '0')}`;
};
</script>
<style scoped lang="scss">
.pc-prompts {
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	margin-top: 40px;
	width: 760px;
	padding: 0;
	font-size: 14px;
	.title {
		color: #999;
		line-height: 14px;
		.split {
			height: 12px;
			width: 2px;
			background-color: #ccc;
			margin: 0 10px;
		}
		span {
			color: rgb(32, 33, 35);
			font-size: 14px;
		}
		.changeBatch {
			color: #999;
			font-size: 12px;
			transition: color 0.2s ease-in-out;
		}
		.change {
			color: #999;
			transition: color 0.2s ease-in-out;
		}
	}
	.main {
		width: calc(100% + 16px);
		display: flex;
		flex-wrap: wrap;
		margin: 4px -8px 0;
		&_item {
			box-sizing: border-box;
			width: calc(50% - 16px);
			margin: 8px;
			padding: 12px;
			border: 1px solid #d9dbde;
			border-radius: 5px;
			background-color: transparent;
			-webkit-transition: border-color 0.2s, background-color 0.2s;
			-o-transition: border-color 0.2s, background-color 0.2s;
			transition: border-color 0.2s, background-color 0.2s;

			.left {
				width: 50px;
				height: 50px;
				border-radius: 5px;
			}
			.color0 {
				background: linear-gradient(180deg, #f63c8b, #fd216c);
			}
			.color1 {
				background: linear-gradient(180deg, #0ebfe1, #0ab2d3);
			}
			.color2 {
				background: linear-gradient(180deg, #9647fe, #7b5be8);
			}
			.color3 {
				background: linear-gradient(180deg, #fb894c, #ff7958);
			}
			.right {
				flex: 1;
				min-width: 0;
				margin-left: 12px;
				h4 {
					color: #202123;
					font-size: 13px;
					font-weight: 500;
					height: 16px;
					transition: background-color 0.2s;
				}
				p {
					font-size: 12px;
					margin-top: 6px;
					height: 34px;
					line-height: 17px;
					color: #8d8e99;
					overflow: hidden;
					-o-text-overflow: ellipsis;
					text-overflow: ellipsis;
					-webkit-line-clamp: 2;
					-webkit-box-orient: vertical;
				}
			}
		}
		&_item_active {
			border: 1px solid #007aff;
			background-color: #ebeef3;
			.right {
				h4 {
					color: #007aff;
				}
			}
		}
	}
}
.tabbar-item {
	width: 108px;
	height: 30px;
	font-size: 13px;
	font-weight: 400;
	line-height: 30px;
	text-align: center;
	cursor: pointer;
	// position: absolute;
	-o-transition: color 0.2s;
	transition: color 0.2s;
	&:nth-child(3) {
		top: 0;
		left: 0;
	}
}
.tabbar-item-active {
	color: #fff;
}
.set-tabbar-active {
	left: 95px;
	color: #fff;
	background-color: #000;
}
.set-input {
	:deep(.el-input__wrapper) {
		border: none;
		outline: none;
		-webkit-box-flex: 1;
		-ms-flex: 1;
		flex: 1;
		min-width: 0;
		height: 100%;
		-webkit-box-sizing: border-box;
		box-sizing: border-box;
		padding: 5px 12px;
		line-height: 20px;
		border-radius: 15px;
		color: #555;
		font-size: 13px;
		background-color: transparent;
		box-shadow: unset;
	}
}
.set-expand-active {
	max-height: 180px;
}
.set-label-active {
	border-color: #1c86ff;
	background-color: #ccdcfb;
	color: #1c86ff;
}
.example-body {
	margin: 10px 0;
	height: 40px;
	font-weight: 400;
	letter-spacing: 0;
	line-height: 20px;
	color: #8b939e;
}
.ellipsis {
	display: -webkit-box;
	-webkit-line-clamp: 2;
	-webkit-box-orient: vertical;
	overflow: hidden;
	-o-text-overflow: ellipsis;
	text-overflow: ellipsis;
	font-size: 12px;
}
.example-bottom {
	margin-top: 10px;
	display: flex;
	-webkit-box-pack: justify;
	-ms-flex-pack: justify;
	justify-content: space-between;
	.example-item {
		background-color: #f0f2f3;
		color: #8b939e;
		border: 1px solid #f5f5f5;
		border-radius: 9px;
		width: 58px;
		height: 18px;
		font-size: 12px;
		line-height: 18px;
		text-align: center;
		cursor: default;
		margin-left: 5px;
	}
	.set-button {
		border: none;
		width: 68px;
		height: 24px;
		color: #fff;
		font-size: 12px;
		background-color: #2a82e4;
		border-radius: 4px;
		cursor: pointer;
	}
}
:deep(.el-drawer__header) {
	padding: 30px 20px 26px !important;
	box-sizing: border-box;
	width: 100%;
	background-color: #e0e7fb;

	position: relative;

	height: unset !important;
	margin-bottom: unset !important;
	border-bottom: unset !important;
}
:deep(.el-drawer__body) {
	overflow-x: hidden;
}
</style>
